@@ -5,11 +5,12 @@ from llm.service import LLMService
 
 
 async def test() -> None:
-    llm = await LLMService.create(claude_3_5_haiku.to_dict())  # noqa: F405
+    llm = await LLMService.create(grok_3_mini.to_dict())  # noqa: F405
     result = await llm.ainvoke(message='Сколько будет 2 + 2?')
     print(result)
     print(llm.usage)
-    print(llm.counter.model_registry.usd_rate)
+    print(llm.usd_rate)
+    print(llm.chat_json)
 
 
 async def main() -> None:
