@@ -5,11 +5,16 @@ from llm.service import LLMService
 
 
 async def test() -> None:
-    llm = await LLMService.create(gpt_4o_mini.to_dict())  # noqa: F405
-    result = llm.astream(message='Расскажи теорему Пифагора')
-    async for chunk in result:
+    llm = await LLMService.create(grok_3_mini.to_dict())  # noqa: F405
+    stream = await llm.astream(message='Кратко расскажи что такое Python')
+    async for chunk in stream:
         print(chunk, end='', flush=True)
 
+    print('\n\n')
+    print(len(stream.full_text))
+    print(llm.usage)
+    print(llm.chat_json)
+
 
 async def main() -> None:
     await test()
