@@ -26,12 +26,13 @@ SYSTEM_PROMPT = (
 
 
 async def test() -> None:
-    llm = await LLMService.create(gpt_4o_mini.to_dict())  # noqa: F405
+    llm = await LLMService.create(grok_3_mini.to_dict())  # noqa: F405
     structured_llm = await llm.with_structured_output(RelatedConceptListOutput)
     result = await structured_llm.ainvoke(message=SYSTEM_PROMPT)
     print(result)
     print(structured_llm.usage)
-    print(structured_llm.counter.model_registry.usd_rate)
+    print(structured_llm.usd_rate)
+    print(structured_llm.chat_json)
 
 
 async def main() -> None:
