@@ -1,5 +1,3 @@
 from .prepare_chat import PrepareChat  # noqa: N999
 
-__all__ = [
-    'PrepareChat',
-]
+__all__ = ('PrepareChat',)
